Module ml_dsa

Module ml_dsa 

Final FIPS 204 ML-DSA parameter constants.

This module implements the parameter sets defined in FIPS 204 (August 2024) “Module-Lattice-Based Digital Signature Standard” https://doi.org/10.6028/NIST.FIPS.204

All constants in this file are taken directly from the final FIPS 204 standard, NOT from earlier CRYSTALS-ML-DSA submissions or draft specifications.

Structs

MlDsa44Params
Structure containing ML-DSA-44 parameters FIPS 204, Table 1: ML-DSA-44 (NIST security category 2)
MlDsa65Params
Structure containing ML-DSA-65 parameters FIPS 204, Table 1: ML-DSA-65 (NIST security category 3)
MlDsa87Params
Structure containing ML-DSA-87 parameters FIPS 204, Table 1: ML-DSA-87 (NIST security category 5)

Constants

FIPS204_SIGN_INTERNAL_MIN_LOOP_LIMIT
FIPS 204 Appendix C, Table 3 minimum allowable loop limit for ML-DSA.Sign_internal.
ML_DSA_44
ML-DSA-44 parameter set (FIPS 204, Table 1) Targets NIST security category 2 (collision resistance of SHA-256)
ML_DSA_65
ML-DSA-65 parameter set (FIPS 204, Table 1) Targets NIST security category 3 (collision resistance of SHA-384)
ML_DSA_87
ML-DSA-87 parameter set (FIPS 204, Table 1) Targets NIST security category 5 (collision resistance of SHA-512)
ML_DSA_N
ML-DSA polynomial degree (n = 256) FIPS 204, Table 1: Common to all ML-DSA parameter sets
ML_DSA_Q
ML-DSA modulus (q = 8380417 = 2²³ - 2¹³ + 1) FIPS 204, Table 1: Common to all ML-DSA parameter sets

Traits

MlDsaSchemeParams
Common trait for ML-DSA parameter sets as defined in FIPS 204